<?php

namespace S\\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use S\\Models\Www;

class WwwPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the www.
     *
     * @param User $user
     * @param Www $www
     *
     * @return bool
     */
    public function view(User $user, Www $www)
    {
        if ($user->canDo('.www.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $www->user_id;
    }

    /**
     * Determine if the given user can create a www.
     *
     * @param User $user
     * @param Www $www
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('.www.create');
    }

    /**
     * Determine if the given user can update the given www.
     *
     * @param User $user
     * @param Www $www
     *
     * @return bool
     */
    public function update(User $user, Www $www)
    {
        if ($user->canDo('.www.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $www->user_id;
    }

    /**
     * Determine if the given user can delete the given www.
     *
     * @param User $user
     * @param Www $www
     *
     * @return bool
     */
    public function delete(User $user, Www $www)
    {
        if ($user->canDo('.www.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $www->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
